@@ -17,6 +17,7 @@ uptimed - Copyright (c) 1998-2004 Rob Kaper <rob@unixcode.org>
 
 #include "../config.h"
 #include "uptimed.h"
+#include "sd-daemon.h"
 
 #ifdef PLATFORM_HPUX
 #define	SYSLOG_PREFIX	"uptimed: "
@@ -28,7 +29,11 @@ uptimed - Copyright (c) 1998-2004 Rob Kaper <rob@unixcode.org>
 #include <getopt.h>
 #endif
 
+#ifdef __ANDROID__
+extern Urec *u_current;
+#else
 Urec *u_current = NULL;
+#endif
 int our_pos=0;
 int update_interval=60, create_bootid=0, send_email=0, foreground=0;
 time_t log_min_uptime = 0, mail_min_uptime = 0;
@@ -38,7 +43,7 @@ char email[EMAIL+1], sendmail[EMAIL+1], pidfile[EMAIL+1];
 int main(int argc, char *argv[])
 {
 	Milestone *next_milestone = NULL, *cheer_milestone = NULL;
-	time_t prev=0;
+	time_t prev=0,tmp=0;
 	int cheer_pos=0;
 	void handler(int);
 
@@ -75,7 +80,6 @@ int main(int argc, char *argv[])
  		}
  	}		
 
-#ifndef PLATFORM_BSD
 	/* Create bootid and exit. Should be done once on startup. */
 	if (create_bootid)
 	{
@@ -83,7 +87,6 @@ int main(int argc, char *argv[])
 		syslog(LOG_INFO, SYSLOG_PREFIX "created bootid: %d", readbootid());
 		exit(0);
 	}
-#endif
 
 	if (update_interval<1)
 		update_interval=1;
@@ -124,6 +127,9 @@ int main(int argc, char *argv[])
 		}
 	}
 
+	sd_notifyf(0, "MAINPID=%lu\n", (unsigned long)getpid());
+	sd_notify(0, "READY=1\n");
+
 	/* The main loop. */
 	while (1)
 	{
@@ -165,6 +171,14 @@ int main(int argc, char *argv[])
 			cheer_milestone = NULL;
 		}
 		
+		/* Update status for service manager */
+		if (next_milestone) {
+			tmp = time(0) + next_milestone->time - u_current->utime;
+			sd_notifyf(0, "STATUS=Next milestone (%s) at %s\n", 
+					next_milestone->desc,
+					ctime(&tmp));
+		}
+
 		/* Save all the records. */
 		save_records(log_max_entries, log_min_uptime);
 
@@ -175,7 +189,7 @@ int main(int argc, char *argv[])
 
 void bg(void)
 {
-	int i;
+	int i, fdmax;
 	/* Simple fork to run proces in the background. */
 	switch(fork())
 	{
@@ -192,7 +206,15 @@ void bg(void)
 	}
 
 	/* Close probably all file descriptors */
-	for (i = 0; i<NOFILE; i++)
+#ifdef HAVE_GETDTABLESIZE
+	fdmax = getdtablesize();
+#else
+	fdmax = sysconf(_SC_OPEN_MAX);
+#endif
+	if (fdmax <= 0)
+		fdmax = 3;
+
+	for (i = 0; i < fdmax; i++)
 		close(i);
 
 	/* Be nice to umount */
@@ -324,6 +346,9 @@ void scan_args(int argc, char *argv[])
 		switch(index)
 		{
 			case '?':
+#ifdef __ANDROID__
+				fputc('\n', stderr);
+#endif
 				print_help(argv);
 				break;
 			case 'v':
